@@ -20,12 +20,13 @@ def updateHistoryActions(isTest):
 	dataDispose.updateHistoryActions()
 
 def testFunc(isTest):
-	disposeData(isTest)
-	#es.setEnv(isTest)
+	#disposeData(isTest)
+	es.setEnv(isTest)
+	#hot.startUpdate(isTest, 'config.ini')
 	#print(es.searchDbConfig())
 	#print('delete post works record: ' + ('success ' if dataDispose.deletePastWorksRecord() else 'fail '))
 	#dataDispose.deletePastWorksRecord()
-	#test.test()
+	test.test()
 	'''
 	while True:
 		es.setEnv(isTest)
