@@ -8,6 +8,9 @@ from subject import Subject, SubjectThread
 
 MaxThreadCount = 3
 
+def createWorks(vid):
+	return Works(vid, 0, 'test', 0)
+
 #删除2个月半之前作品的推荐记录
 def deletePastWorksRecord():
 	vids = []
@@ -66,12 +69,7 @@ def getWorksList():
 			worksList.append(works)
 	return worksList
 
-def updateHistoryActions():
-	worksList = getWorksList()
-	subjectList = []
-
-	endTime = getZeroTime()
-
+def updateWorksHistoryActions(worksList, endTime, startTime=0, needCreateLimit=False):
 	worksThreads = []
 
 	while len(worksList) != 0:
@@ -81,7 +79,7 @@ def updateHistoryActions():
 		else:
 			works = worksList.pop()
 			print(len(worksList), works.vid, works.aid)
-			t = WorksThread(works, endTime)
+			t = WorksThread(works, endTime, startTime, needCreateLimit)
 			worksThreads.append(t)
 			t.setDaemon(True)
 			t.start()
@@ -90,6 +88,31 @@ def updateHistoryActions():
 		#time.sleep(1)
 		pass
 
+	for t in worksThreads:
+		worksList.append(t.works)
+
+def updateHistoryActions():
+	worksList = getWorksList()
+	subjectList = []
+
+	zeroTime = getZeroTime()
+	zeroTimeMonthBefore = zeroTime - 60 * 24 * 60 * 60
+
+	updateWorksHistoryActions(worksList, zeroTimeMonthBefore)
+
+	from .. import hot
+	hot.calWorksScore(worksList)
+
+	updateWorksHistoryActions(worksList, zeroTime, zeroTimeMonthBefore, True)
+
+	worksHistory = {}
+	for works in worksList:
+		worksHistory[works.vid] = works.toSaveEsData()
+
+	return es.coverStatisticsDataReal('works_history', worksHistory)
+
+
+	'''
 	subjectAids = []
 
 	for t in worksThreads:
@@ -136,17 +159,12 @@ def updateHistoryActions():
 		subjectHistory[subject.aid] = subject.toSaveEsData()
 	if not es.coverStatisticsDataReal('subject_history', subjectHistory):
 		return False
-
-	hot.calWorksScore(worksList)
-	worksHistory = {}
-	for works in worksList:
-		worksHistory[works.vid] = works.toSaveEsData()
-	return es.coverStatisticsDataReal('works_history', worksHistory)
+	'''
 
 			
 def toWorks(worksInfo):
 	if worksInfo.has_key('vid') or worksInfo.has_key('aid') or worksInfo.has_key('title'):
-		return Works(worksInfo['vid'], worksInfo['aid'], worksInfo['title'], worksInfo['publishtime'], worksInfo['duration'] if worksInfo.has_key('duration') else 0)
+		return Works(worksInfo['vid'], worksInfo['aid'], worksInfo['title'], worksInfo['publishtime'])
 
 #当天零点秒数
 def getZeroTime():
@@ -204,9 +222,9 @@ def disposePersonasOnce(worksDict):
 					_time = es.timeToEsLocalTime(float(items[0]))
 					addUserAction(userActions, _id, createTime, items[2], _time, uid, items)
 					addWorksAction(worksDict, worksActions, _id, createTime, items[2], _time, uid, items)
-					addWorksPlayer(worksPlayers, items[2], uid, items)
+					#addWorksPlayer(worksPlayers, items[2], uid, items)
 			except Exception as error:
-				print('dispose personas action error: ' + str(error))
+				print('dispose personas action (' + str(action) + ') error: ' + str(error))
 			aIndex += 1
 
 		startTime = max(startTime, createTime)
@@ -322,7 +340,7 @@ def addWorksAction(worksDict, worksActions, _id, createTime, actionId, _time, ui
 		action = 13
 		value = 1
 	elif simpleStatisticsMap.has_key(actionId):
-		vid = items[4 if actionId in [10, 11] else 3]
+		vid = items[4 if actionId in ['10', '11'] else 3]
 		action = simpleStatisticsMap[actionId]
 		value = 1
 	else:
