@@ -19,6 +19,25 @@ def setEnv(test):
 	global isTest
 	isTest = test
 
+vidDict = {}
+def getIntByVid(vid):
+	global vidDict
+	if vidDict.has_key(vid):
+		return vidDict[vid]
+	else:
+		i = getIntByVidInRedis(vid)
+		vidDict[vid] = i
+		return i
+
+recommendRedisPool = redis.ConnectionPool(host='r-bp160ebab6e97594.redis.rds.aliyuncs.com', port='6379', db=0, password='flrjovlOJEROIJ324')
+
+def getIntByVidInRedis(vid):
+	recommendRedis = redis.Redis(connection_pool=recommendRedisPool)
+	#return recommendRedis.get(vid)
+	print(recommendRedis.get(vid))
+	#print(recommendRedis.lrange('recommendcache:videouserrecord:uid;177701952', 0, sys.maxint))
+
+
 def updateRedisWorksHots(worksHots):
 	r = redis.Redis(host='r-wz9536616f776d74.redis.rds.aliyuncs.com', port=6379, db=3, password='Idltest503') if isTest else redis.Redis(host='r-bp17063fe90e0e64.redis.rds.aliyuncs.com', port=6379, db=0, password='flrjovlOJEROIJ324')
 	
@@ -137,13 +156,15 @@ def updateStatisticsDocResolve(index, doc):
 	#hot list额外在开发环境存一份用于测试
 	#if isTest and index == 'works_hot':
 	#	esUpdateStatisticsDocResolve(devEsclient, index, doc)
-	success = esUpdateStatisticsDocResolve(getEsclient(), index, doc)
+	success = esUpdateStatisticsDocResolve(getEsclient('statistics_' + index + '_write'), index, doc)
 	#正式环境works_actions存一份在本地es用于离线训练
+	'''
 	try:
 		if not isTest and index == 'works_actions':
 			esUpdateStatisticsDocResolve(localEsclient, index, doc)
 	except Exception as error:
 		print('save local es error: ' + str(error))
+	'''
 
 	return success
 
@@ -202,7 +223,7 @@ def scrollSearch(fullIndex, doc_type, body, searchAll=True, log=True, version=Fa
 	return hits
 
 def getEsclient(fullIndex=None):
-	return testEsclient if isTest else relEsclient if fullIndex == 'works_video_read' else dataEsclient
+	return testEsclient if isTest else relEsclient if fullIndex == 'works_video_read' else localEsclient if fullIndex in ['statistics_works_hot_grow_write', 'statistics_works_hot_simulation_write', 'statistics_works_history_read', 'statistics_works_history_write'] else dataEsclient
 
 def timeToEsLocalTime(pTime):
 	return time.strftime('%Y-%m-%dT%H:%M:%S+0800', time.localtime(pTime))
